# Pyneers

[![Pull Workflow](https://github.com/amagimedia/pyneers/actions/workflows/on-pull-request.yaml/badge.svg)](https://github.com/amagimedia/pyneers/actions) [![Push Workflow](https://github.com/amagimedia/pyneers/actions/workflows/on-push.yaml/badge.svg)](https://github.com/amagimedia/pyneers/actions)


Pyneers is a test automation framework for `Python` using `Pytest`.
It allows you to easily set up a new test project.

It also contains `pyneers cli` which can be used to setup the initial repo structure.

## Installation
To use Pyneers, you need to install it using Poetry. Since Poetry requires a pyproject.toml file for installation, follow these steps:

1. Install poetry
    ```sh
    pip install poetry
    ```

2. Configure poetry settings (below settings ensure that a .venv folder is created in same project directory)-
    ```sh
    poetry config virtualenvs.create true &&  poetry config virtualenvs.in-project true
    ```

3. Create a minimal `pyproject.toml` file for the test repo using below command-
    ```sh
    poetry init
    ```

    This should create a file like below-
    ```toml
    [tool.poetry]
    name = "repo_name"
    version = "0.1.0"
    description = "Test Automation Repo"
    authors = ["Your name"]

    [build-system]
    requires = ["poetry-core>=1.1.0"]
    build-backend = "poetry.core.masonry.api"

    [tool.poetry.dependencies]
    python = "^3.11"
    ```

4. Add the `pyneers` package using poetry-


    `Option 1`: Using internal pypi (`Recommended`)
    ```sh
    poetry source add --priority=explicit amagi http://pypi.iota.amagi.tv
    ```

    ```sh
    poetry add pyneers --source amagi --no-cache
    ```

    `Option 2`: Using github artifacts path
    ```sh
    poetry add pyneers@git+https://github.com/amagimedia/pyneers.git@v0.1.1
    ```

5. Install the package
    ```sh
    poetry install
    ```

5. Activate virtualenv
    ```sh
    source .venv/bin/activate
    ```
    or if you are using an IDE like `Pycharm` it will by default activate the `venv` virtual environment for you.

6. Set PYTHONPATH to current working directory
    ```sh
    export PYTHONPATH="${PYTHONPATH}:$(pwd)"
    ```
Now you are ready to write and run tests

## Usage
Once the pyneers package is installed, you can use the `pyneers cli` with following commands:

### Initialize a New Boilerplate Pyneers Project
To create a new boilerplate test project, run the following command in your current project folder:
```sh
pyneers init
```
This command will initialize the project structure and generate the necessary files for your Pyneers project.

### Running Pyneers Tests
After initializing your Pyneers project, you can use `Pytest` to run your tests.

Pyneers is built on top of Pytest, so you can use all the standard Pytest commands to run your tests.
```sh
pytest <path_to_test_file_or_folder>
```
Replace <path_to_test_file_or_folder> with the path to the test file or folder you want to run.

---
### Docs

* [pyneers](https://effective-adventure-29wlj4q.pages.github.io/)
* [playwright](https://playwright.dev/docs/intro)
*  [requests](https://requests.readthedocs.io/en/latest/)
* [httpx](https://www.python-httpx.org/)
